@@ -15,7 +15,7 @@ ConnectionError = _librabbitmq.ConnectionError
 ChannelError = _librabbitmq.ChannelError
 
 
-__version__ = '1.0.0'
+__version__ = '1.0.2'
 __all__ = ['Connection', 'Message', 'ConnectionError', 'ChannelError']
 
 
@@ -57,7 +57,7 @@ class Channel(object):
     def flow(self, active):
         return self.connection._flow(self.channel_id, active)
 
-    def recover(self, requeue=True):
+    def basic_recover(self, requeue=True):
         return self.connection._basic_recover(self.channel_id, requeue)
 
     def basic_get(self, queue='', no_ack=False):
@@ -91,8 +91,14 @@ class Channel(object):
 
     def basic_cancel(self, consumer_tag, **kwargs):
         self.no_ack_consumers.discard(consumer_tag)
-        self.connection.callbacks[self.channel_id].pop(consumer_tag, None)
-        self.connection._basic_cancel(self.channel_id, consumer_tag)
+        if self.connection:
+            try:
+                callbacks = self.connection.callbacks[self.channel_id]
+            except KeyError:
+                pass
+            else:
+                callbacks.pop(consumer_tag, None)
+            self.connection._basic_cancel(self.channel_id, consumer_tag)
 
     def basic_publish(self, body, exchange='', routing_key='',
             mandatory=False, immediate=False, **properties):
@@ -134,10 +140,10 @@ class Channel(object):
         return self.connection._queue_bind(self.channel_id,
                 queue, exchange, routing_key, arguments or {})
 
-    def queue_unbind(self, queue='', exchange='', binding_key='',
+    def queue_unbind(self, queue='', exchange='', routing_key='',
             arguments=None, nowait=False):
         return self.connection._queue_unbind(self.channel_id,
-                queue, exchange, binding_key, arguments or {})
+                queue, exchange, routing_key, arguments or {})
 
     def queue_delete(self, queue='', if_unused=False, if_empty=False,
             nowait=False):
@@ -146,7 +152,8 @@ class Channel(object):
                 queue, if_unused, if_empty)
 
     def close(self):
-        self.connection._remove_channel(self)
+        if self.connection:
+            self.connection._remove_channel(self)
 
 
 class Connection(_librabbitmq.Connection):
